@@ -1,11 +1,6 @@
-// **********************************************************************
 //
-// Copyright (c) 2003-2018 ZeroC, Inc. All rights reserved.
+// Copyright (c) ZeroC, Inc. All rights reserved.
 //
-// This copy of Ice is licensed to you under the terms described in the
-// ICE_LICENSE file included in this distribution.
-//
-// **********************************************************************
 
 #ifndef ICE_CONFIG_H
 #define ICE_CONFIG_H
@@ -31,6 +26,10 @@
 #   endif
 #endif
 
+#ifdef ICE_SWIFT
+#   include <dispatch/dispatch.h>
+#endif
+
 //
 // Define the Ice and IceInternal namespace, so that we can use the following
 // everywhere in our code:
