@@ -1,11 +1,6 @@
-// **********************************************************************
 //
-// Copyright (c) 2003-2017 ZeroC, Inc. All rights reserved.
+// Copyright (c) ZeroC, Inc. All rights reserved.
 //
-// This copy of Ice is licensed to you under the terms described in the
-// ICE_LICENSE file included in this distribution.
-//
-// **********************************************************************
 
 //
 // Ice::optional is a placeholder for std::optional:
@@ -545,15 +540,30 @@ public:
     return dataptr();
   }
 
+    //
+    // WORKAROUND error: implicit conversion turns string literal into bool
+    //
+#if defined(__clang__)
+#   pragma clang diagnostic push
+#   pragma clang diagnostic ignored "-Wconversion"
+#endif
   constexpr T const& operator *() const {
     return TR2_OPTIONAL_ASSERTED_EXPRESSION(initialized(), contained_val());
   }
 
+#if defined(__clang__)
+#   pragma clang diagnostic pop
+#endif
+
   T& operator *() {
     assert (initialized());
     return contained_val();
   }
 
+#ifdef _MSC_VER
+#   pragma warning(push)
+#   pragma warning(disable:4702) // unreachable code
+#endif
   constexpr T const& value() const {
     return initialized() ? contained_val() : (throw bad_optional_access("bad optional access"), contained_val());
   }
@@ -562,6 +572,10 @@ public:
     return initialized() ? contained_val() : (throw bad_optional_access("bad optional access"), contained_val());
   }
 
+#ifdef _MSC_VER
+#   pragma warning(pop)
+#endif
+
 # endif
 
 # if OPTIONAL_HAS_THIS_RVALUE_REFS == 1
@@ -1041,8 +1055,13 @@ namespace std
 # undef TR2_OPTIONAL_REQUIRES
 # undef TR2_OPTIONAL_ASSERTED_EXPRESSION
 
-namespace Ice{
+namespace Ice
+{
 
+/**
+ * Ice::optional is a placeholder for std::optional.
+ * Refer to http://en.cppreference.com/w/cpp/utility/optional for more information.
+ */
 template<class T> using optional = std::experimental::Ice::optional<T>;
 
 using std::experimental::Ice::operator==;
@@ -1052,25 +1071,36 @@ using std::experimental::Ice::operator<=;
 using std::experimental::Ice::operator>;
 using std::experimental::Ice::operator>=;
 
+/** Creates an optional object. */
 using std::experimental::Ice::make_optional;
+/** Exchanges the state of an optional object with another one. */
 using std::experimental::Ice::swap;
 
+/** This type indicates that no value is provided. */
 using nullopt_t = std::experimental::Ice::nullopt_t;
+/** An instance of nullopt_t used as a marker value to indicate that no value is provided. */
 using std::experimental::Ice::nullopt;
 
+/** Raised when accessing an optional that doesn't contain a value. */
 using bad_optional_access = std::experimental::Ice::bad_optional_access;
 
+/** This type indicates that an optional value should be constructed in place. */
 using in_place_t = std::experimental::Ice::in_place_t;
+/** An instance of in_place_t that indicates that an optional value should be constructed in place. */
 using std::experimental::Ice::in_place;
 
 }
 
-//
-// For compatibility with the Ice C++98 mapping, do not use in new code:
-//
-namespace IceUtil{
+namespace IceUtil
+{
 
+/**
+ * For compatibility with the Ice C++98 mapping, do not use in new code:
+ */
 template<class T> using Optional = std::experimental::Ice::optional<T>;
+/**
+ * For compatibility with the Ice C++98 mapping, do not use in new code:
+ */
 constexpr std::experimental::Ice::nullopt_t None{std::experimental::Ice::nullopt_t::init()};
 
 }
