@@ -1,11 +1,6 @@
-// **********************************************************************
 //
-// Copyright (c) 2003-2018 ZeroC, Inc. All rights reserved.
+// Copyright (c) ZeroC, Inc. All rights reserved.
 //
-// This copy of Ice is licensed to you under the terms described in the
-// ICE_LICENSE file included in this distribution.
-//
-// **********************************************************************
 
 #ifndef ICE_UTIL_SCANNER_CONFIG_H
 #define ICE_UTIL_SCANNER_CONFIG_H
@@ -13,7 +8,7 @@
 #include <IceUtil/Config.h> // Required by generated Scanners.
 
 //
-// COMPILERFIX: VC compilers does not provide stdint.h header until VC100
+// COMPILERFIX: VC compilers does not provide stdint.h header until v100
 // the header must be included before that macros for integral types
 // in flex generated Scanners are defined.
 //
@@ -35,4 +30,10 @@
 #   pragma warning(disable:5033)
 #endif
 
+#if defined(__clang__)
+#   pragma clang diagnostic ignored "-Wconversion"
+#   pragma clang diagnostic ignored "-Wsign-conversion"
+#   pragma clang diagnostic ignored "-Wdocumentation"
+#endif
+
 #endif
